import { defineMiddleware, sequence } from "astro:middleware";

const protectedRoutes = defineMiddleware(async (ctx, next) => {
	const pathname = ctx.url.pathname;
	if (
		!["/", "/register", "/logout"].includes(pathname) &&
		!pathname.startsWith("/api")
	) {
		const jwt = ctx.cookies.get("jwt");
		if (!jwt) {
			return ctx.redirect(`/?redirect=${pathname}`);
		}

		const jwtValue = jwt.value;
		const res = await fetch(`${import.meta.env.API_URL}/accounts/recovery`, {
			credentials: "include",
			headers: {
				Authorization: `Bearer ${jwtValue}`,
			},
		});

		if (res.status !== 200) {
			return ctx.redirect(`/?redirect=${pathname}`);
		}

		ctx.locals.account = JSON.parse(await res.text()).account;
	}

	return await next();
});

export const onRequest = sequence(defineMiddleware(protectedRoutes));
