import type { APIRoute } from "astro";

export const POST: APIRoute = async ({ request, cookies }) => {
	const jwt = cookies.get("jwt")?.value as string;
	const reqBody = await request.text();
	if (!reqBody) throw new Error("body not found");

	const res = await fetch(`${import.meta.env.API_URL}/movies`, {
		method: "POST",
		body: reqBody,
		headers: {
			"Content-Type": "application/json",
			Authorization: `Bearer ${jwt}`,
		},
	});

	const resBody = await res.text();
	return new Response(resBody, { status: res.status });
};

export const GET: APIRoute = async ({ request, cookies }) => {
	const jwt = cookies.get("jwt")?.value as string;
	const url = new URL(request.url);

	const res = await fetch(
		`${import.meta.env.API_URL}/movies/search?q=${url.searchParams.get("query")}`,
		{
			method: "GET",
			headers: {
				"Content-Type": "application/json",
				Authorization: `Bearer ${jwt}`,
			},
		},
	);

	const resBody = await res.text();
	return new Response(resBody, { status: res.status });
};
